package com.hw.ems.base.mapper;

import com.hw.ems.base.domain.BasePublicUserRecord;

import java.util.List;

/**
 * 公摊用户数据记录Mapper接口
 *
 * @author YinQ
 * @date 2023-06-25
 */
public interface BasePublicUserRecordMapper
{
    /**
     * 查询公摊用户数据记录
     *
     * @param objid 公摊用户数据记录主键
     * @return 公摊用户数据记录
     */
    public BasePublicUserRecord selectBasePublicUserRecordByObjid(Long objid);

    /**
     * 查询公摊用户数据记录列表
     *
     * @param basePublicUserRecord 公摊用户数据记录
     * @return 公摊用户数据记录集合
     */
    public List<BasePublicUserRecord> selectBasePublicUserRecordList(BasePublicUserRecord basePublicUserRecord);

    /**
     * 新增公摊用户数据记录
     *
     * @param basePublicUserRecord 公摊用户数据记录
     * @return 结果
     */
    public int insertBasePublicUserRecord(BasePublicUserRecord basePublicUserRecord);

    /**
     * 修改公摊用户数据记录
     *
     * @param basePublicUserRecord 公摊用户数据记录
     * @return 结果
     */
    public int updateBasePublicUserRecord(BasePublicUserRecord basePublicUserRecord);

    /**
     * 删除公摊用户数据记录
     *
     * @param objid 公摊用户数据记录主键
     * @return 结果
     */
    public int deleteBasePublicUserRecordByObjid(Long objid);

    /**
     * 批量删除公摊用户数据记录
     *
     * @param objids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteBasePublicUserRecordByObjids(Long[] objids);
}
